==> ffcuesplitter-1.0.6-py3-none-any.whl: ffcuesplitter/info.py <==
"""
Name: info.py
Porpose: useful information strings
Writer: jeanslack <jeanlucperni@gmail.com>
license: GPL3
Rev: February 03 2022
####################################################################

This file is part of ffcuesplitter.

    ffcuesplitter is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    ffcuesplitter is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with ffcuesplitter.  If not, see <http://www.gnu.org/licenses/>.
"""
__author__ = "Gianluca Pernigotto - Jeanslack"
__contact__ = '<jeanlucperni@gmail.com>'
__maintainer__ = "Gianluca Pernigotto - Jeanslack"
__maintainer_contact__ = "jeanlucperni@gmail.com"
__copyleft__ = '2022'
__version__ = '1.0.6'
__release__ = 'February  04 2022'
__appname__ = "FFcuesplitter"
__packagename__ = "ffcuesplitter"
__license__ = "GPL3 (Gnu Public License)"
__projecturl__ = "https://github.com/jeanslack/FFcuesplitter"
__githuburl__ = "https://github.com/jeanslack/FFcuesplitter"
__description__ = ("FFmpeg based audio splitter for audio CD "
                   "images supplied with CUE sheet files.")
__descriptionfull__ = """FFcuesplitter is a multi-platform CUE sheet splitter
entirely based on FFmpeg. Splits big audio tracks and automatically embeds tags
using the information contained in the associated **"CUE"** sheet. It supports
many input formats (due to FFmpeg), including APE format, without need
installing extra audio libs or packages. automatically support multiple
CUE sheet encodings. Can be used both as a Python module (API) and in command
line mode."""
__license__ = "GPL3 (Gnu Public License)"
__licensefull__ = f"""
Copyright - {__copyleft__} {__author__}
Author and Developer: {__author__}
Mail: {__contact__}

FFcuesplitter is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FFcuesplitter is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FFcuesplitter.  If not, see <http://www.gnu.org/licenses/>.
"""

==> ffcuesplitter-1.0.8-py3-none-any.whl: ffcuesplitter/info.py <==
"""
Name: info.py
Porpose: useful information strings
Writer: jeanslack <jeanlucperni@gmail.com>
license: GPL3
Rev: February 03 2022
####################################################################

This file is part of FFcuesplitter.

    FFcuesplitter is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    FFcuesplitter is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with FFcuesplitter.  If not, see <http://www.gnu.org/licenses/>.
"""
__author__ = "Gianluca Pernigotto - Jeanslack"
__contact__ = '<jeanlucperni@gmail.com>'
__maintainer__ = "Gianluca Pernigotto - Jeanslack"
__maintainer_contact__ = "jeanlucperni@gmail.com"
__copyleft__ = '2022'
__version__ = '1.0.8'
__release__ = 'February  17 2022'
__appname__ = "FFcuesplitter"
__packagename__ = "ffcuesplitter"
__license__ = "GPL3 (Gnu Public License)"
__projecturl__ = "https://github.com/jeanslack/FFcuesplitter"
__githuburl__ = "https://github.com/jeanslack/FFcuesplitter"
__description__ = ("FFmpeg based audio splitter for audio CD "
                   "images supplied with CUE sheet files.")
__descriptionfull__ = """FFcuesplitter is a multi-platform CUE sheet splitter
entirely based on FFmpeg. Splits big audio tracks and automatically embeds tags
using the information contained in the associated **"CUE"** sheet. It supports
many input formats (due to FFmpeg), including APE format, without need
installing extra audio libs or packages. automatically support multiple
CUE sheet encodings. Can be used both as a Python module (API) and in command
line mode."""
__license__ = "GPL3 (Gnu Public License)"
__licensefull__ = f"""
Copyright - {__copyleft__} {__author__}
Author and Developer: {__author__}
Mail: {__contact__}

FFcuesplitter is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

FFcuesplitter is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FFcuesplitter.  If not, see <http://www.gnu.org/licenses/>.
"""
